import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:scribble/scribble.dart';

void main() {
  group(".fromJson", () {
    test('can deserialize example sketch', () async {
      final json = jsonDecode(exampleJson) as Map<String, dynamic>;
      final sketch = Sketch.fromJson(json);
      expect(sketch.lines.length, 14);
      expect(sketch.lines.where((l) => l.color == 0xFF000000).length, 10);
      expect(sketch.lines.where((l) => l.color == Colors.red.value).length, 1);
      expect(
        sketch.lines.where((l) => l.color == Colors.green.value).length,
        1,
      );
      expect(sketch.lines.where((l) => l.color == Colors.blue.value).length, 1);
      expect(
        sketch.lines.where((l) => l.color == Colors.yellow.value).length,
        1,
      );
    });
  });
}

const exampleJson = '''
{
  "lines" : [
    {
      "points" : [
        {
          "x" : 251.38671875,
          "y" : 128.421875,
          "pressure" : 0.5
        },
        {
          "x" : 248.01953125,
          "y" : 127.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 244.1484375,
          "y" : 127.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 238.6640625,
          "y" : 127.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 232.55859375,
          "y" : 127.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 226.12109375,
          "y" : 127.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 219.31640625,
          "y" : 127.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 213.4140625,
          "y" : 127.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 208.31640625,
          "y" : 127.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 203.2734375,
          "y" : 127.98828125,
          "pressure" : 0.5
        },
        {
          "x" : 198.875,
          "y" : 128.5234375,
          "pressure" : 0.5
        },
        {
          "x" : 195.66796875,
          "y" : 129.55078125,
          "pressure" : 0.5
        },
        {
          "x" : 193.421875,
          "y" : 130.83984375,
          "pressure" : 0.5
        },
        {
          "x" : 191.0859375,
          "y" : 133.12109375,
          "pressure" : 0.5
        },
        {
          "x" : 190.39453125,
          "y" : 135.1328125,
          "pressure" : 0.5
        },
        {
          "x" : 189.9609375,
          "y" : 138.9609375,
          "pressure" : 0.5
        },
        {
          "x" : 189.26171875,
          "y" : 142.29296875,
          "pressure" : 0.5
        },
        {
          "x" : 188.69921875,
          "y" : 145.34765625,
          "pressure" : 0.5
        },
        {
          "x" : 188.1328125,
          "y" : 148.65234375,
          "pressure" : 0.5
        },
        {
          "x" : 187.6875,
          "y" : 152.09375,
          "pressure" : 0.5
        },
        {
          "x" : 187.515625,
          "y" : 155.125,
          "pressure" : 0.5
        },
        {
          "x" : 187.515625,
          "y" : 157.44921875,
          "pressure" : 0.5
        },
        {
          "x" : 187.515625,
          "y" : 161.11328125,
          "pressure" : 0.5
        },
        {
          "x" : 187.66015625,
          "y" : 163.1640625,
          "pressure" : 0.5
        },
        {
          "x" : 188.4765625,
          "y" : 166.11328125,
          "pressure" : 0.5
        },
        {
          "x" : 190.84765625,
          "y" : 171.08984375,
          "pressure" : 0.5
        },
        {
          "x" : 195.6328125,
          "y" : 178.484375,
          "pressure" : 0.5
        },
        {
          "x" : 203.015625,
          "y" : 187.28515625,
          "pressure" : 0.5
        },
        {
          "x" : 212.51953125,
          "y" : 196.58203125,
          "pressure" : 0.5
        },
        {
          "x" : 222.53515625,
          "y" : 204.8671875,
          "pressure" : 0.5
        },
        {
          "x" : 230.6875,
          "y" : 210.8125,
          "pressure" : 0.5
        },
        {
          "x" : 237.16015625,
          "y" : 214.859375,
          "pressure" : 0.5
        },
        {
          "x" : 243.859375,
          "y" : 218.1953125,
          "pressure" : 0.5
        },
        {
          "x" : 250.48828125,
          "y" : 220.578125,
          "pressure" : 0.5
        },
        {
          "x" : 256.796875,
          "y" : 222.33984375,
          "pressure" : 0.5
        },
        {
          "x" : 263.20703125,
          "y" : 224.33984375,
          "pressure" : 0.5
        },
        {
          "x" : 270.2734375,
          "y" : 226.7890625,
          "pressure" : 0.5
        },
        {
          "x" : 277.28125,
          "y" : 229.26171875,
          "pressure" : 0.5
        },
        {
          "x" : 282.484375,
          "y" : 231.37890625,
          "pressure" : 0.5
        },
        {
          "x" : 286.7890625,
          "y" : 233.37890625,
          "pressure" : 0.5
        },
        {
          "x" : 290.671875,
          "y" : 235.3203125,
          "pressure" : 0.5
        },
        {
          "x" : 293.80078125,
          "y" : 237.16796875,
          "pressure" : 0.5
        },
        {
          "x" : 296.53125,
          "y" : 239.20703125,
          "pressure" : 0.5
        },
        {
          "x" : 299.23828125,
          "y" : 241.7265625,
          "pressure" : 0.5
        },
        {
          "x" : 302.4453125,
          "y" : 244.9609375,
          "pressure" : 0.5
        },
        {
          "x" : 305.953125,
          "y" : 248.8671875,
          "pressure" : 0.5
        },
        {
          "x" : 309.25390625,
          "y" : 252.7734375,
          "pressure" : 0.5
        },
        {
          "x" : 312.421875,
          "y" : 256.91015625,
          "pressure" : 0.5
        },
        {
          "x" : 315.046875,
          "y" : 260.9921875,
          "pressure" : 0.5
        },
        {
          "x" : 316.765625,
          "y" : 264.0546875,
          "pressure" : 0.5
        },
        {
          "x" : 317.83984375,
          "y" : 266.20703125,
          "pressure" : 0.5
        },
        {
          "x" : 318.328125,
          "y" : 268.91796875,
          "pressure" : 0.5
        },
        {
          "x" : 317.6171875,
          "y" : 271.2109375,
          "pressure" : 0.5
        },
        {
          "x" : 315.63671875,
          "y" : 273.78515625,
          "pressure" : 0.5
        },
        {
          "x" : 312.546875,
          "y" : 277.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 308.99609375,
          "y" : 281.91015625,
          "pressure" : 0.5
        },
        {
          "x" : 305.921875,
          "y" : 286.015625,
          "pressure" : 0.5
        },
        {
          "x" : 303.703125,
          "y" : 288.9453125,
          "pressure" : 0.5
        },
        {
          "x" : 302.2734375,
          "y" : 290.69921875,
          "pressure" : 0.5
        },
        {
          "x" : 300.71484375,
          "y" : 292.01953125,
          "pressure" : 0.5
        },
        {
          "x" : 298.37109375,
          "y" : 292.50390625,
          "pressure" : 0.5
        },
        {
          "x" : 295.34375,
          "y" : 293.5546875,
          "pressure" : 0.5
        },
        {
          "x" : 292.171875,
          "y" : 295.28515625,
          "pressure" : 0.5
        },
        {
          "x" : 288.2734375,
          "y" : 297.61328125,
          "pressure" : 0.5
        },
        {
          "x" : 283.984375,
          "y" : 300.1796875,
          "pressure" : 0.5
        },
        {
          "x" : 280.04296875,
          "y" : 302.5625,
          "pressure" : 0.5
        },
        {
          "x" : 277,
          "y" : 304.0625,
          "pressure" : 0.5
        },
        {
          "x" : 273.64453125,
          "y" : 305.34375,
          "pressure" : 0.5
        },
        {
          "x" : 269.0625,
          "y" : 306.734375,
          "pressure" : 0.5
        },
        {
          "x" : 263.1328125,
          "y" : 308.0078125,
          "pressure" : 0.5
        },
        {
          "x" : 255.5078125,
          "y" : 309.16015625,
          "pressure" : 0.5
        },
        {
          "x" : 246.39453125,
          "y" : 310.15625,
          "pressure" : 0.5
        },
        {
          "x" : 236.375,
          "y" : 311.09765625,
          "pressure" : 0.5
        },
        {
          "x" : 226.4296875,
          "y" : 311.53125,
          "pressure" : 0.5
        },
        {
          "x" : 217.31640625,
          "y" : 311.53125,
          "pressure" : 0.5
        },
        {
          "x" : 209.0859375,
          "y" : 311.53125,
          "pressure" : 0.5
        },
        {
          "x" : 201.58203125,
          "y" : 311.39453125,
          "pressure" : 0.5
        },
        {
          "x" : 194.1015625,
          "y" : 310.40234375,
          "pressure" : 0.5
        },
        {
          "x" : 186.015625,
          "y" : 307.94921875,
          "pressure" : 0.5
        },
        {
          "x" : 178.15625,
          "y" : 304.08984375,
          "pressure" : 0.5
        },
        {
          "x" : 172.1640625,
          "y" : 300.1953125,
          "pressure" : 0.5
        },
        {
          "x" : 167.52734375,
          "y" : 296.61328125,
          "pressure" : 0.5
        },
        {
          "x" : 164.140625,
          "y" : 293.5,
          "pressure" : 0.5
        },
        {
          "x" : 163.12109375,
          "y" : 290.671875,
          "pressure" : 0.5
        }
      ],
      "color" : 4278190080,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 429.8359375,
          "y" : 229.109375,
          "pressure" : 0.5
        },
        {
          "x" : 425.69140625,
          "y" : 229.109375,
          "pressure" : 0.5
        },
        {
          "x" : 421.45703125,
          "y" : 229.109375,
          "pressure" : 0.5
        },
        {
          "x" : 415.8671875,
          "y" : 229.109375,
          "pressure" : 0.5
        },
        {
          "x" : 411.13671875,
          "y" : 229.109375,
          "pressure" : 0.5
        },
        {
          "x" : 407.1640625,
          "y" : 229.109375,
          "pressure" : 0.5
        },
        {
          "x" : 402.3359375,
          "y" : 229.109375,
          "pressure" : 0.5
        },
        {
          "x" : 396.98046875,
          "y" : 229.109375,
          "pressure" : 0.5
        },
        {
          "x" : 390.4609375,
          "y" : 229.671875,
          "pressure" : 0.5
        },
        {
          "x" : 382.9375,
          "y" : 232.16796875,
          "pressure" : 0.5
        },
        {
          "x" : 375.1953125,
          "y" : 236.640625,
          "pressure" : 0.5
        },
        {
          "x" : 368.234375,
          "y" : 241.7890625,
          "pressure" : 0.5
        },
        {
          "x" : 362.59765625,
          "y" : 246.90234375,
          "pressure" : 0.5
        },
        {
          "x" : 358.078125,
          "y" : 251.78125,
          "pressure" : 0.5
        },
        {
          "x" : 354.9453125,
          "y" : 255.9765625,
          "pressure" : 0.5
        },
        {
          "x" : 352.72265625,
          "y" : 259.71484375,
          "pressure" : 0.5
        },
        {
          "x" : 351.12890625,
          "y" : 263.140625,
          "pressure" : 0.5
        },
        {
          "x" : 350.2734375,
          "y" : 265.6875,
          "pressure" : 0.5
        },
        {
          "x" : 349.98828125,
          "y" : 267.69140625,
          "pressure" : 0.5
        },
        {
          "x" : 350.6328125,
          "y" : 272.265625,
          "pressure" : 0.5
        },
        {
          "x" : 352.98046875,
          "y" : 276.3984375,
          "pressure" : 0.5
        },
        {
          "x" : 356.45703125,
          "y" : 281.38671875,
          "pressure" : 0.5
        },
        {
          "x" : 360.0234375,
          "y" : 286.5390625,
          "pressure" : 0.5
        },
        {
          "x" : 362.8671875,
          "y" : 290.8046875,
          "pressure" : 0.5
        },
        {
          "x" : 364.58984375,
          "y" : 293.18359375,
          "pressure" : 0.5
        },
        {
          "x" : 366.95703125,
          "y" : 294.72265625,
          "pressure" : 0.5
        },
        {
          "x" : 369.81640625,
          "y" : 294.984375,
          "pressure" : 0.5
        },
        {
          "x" : 376.92578125,
          "y" : 294.984375,
          "pressure" : 0.5
        },
        {
          "x" : 387.6015625,
          "y" : 294.984375,
          "pressure" : 0.5
        },
        {
          "x" : 400.12109375,
          "y" : 294.984375,
          "pressure" : 0.5
        },
        {
          "x" : 414.05859375,
          "y" : 294.984375,
          "pressure" : 0.5
        },
        {
          "x" : 425.6484375,
          "y" : 294.84375,
          "pressure" : 0.5
        },
        {
          "x" : 433.58984375,
          "y" : 294.2578125,
          "pressure" : 0.5
        },
        {
          "x" : 439.1484375,
          "y" : 293.41796875,
          "pressure" : 0.5
        },
        {
          "x" : 443.3515625,
          "y" : 292.2890625,
          "pressure" : 0.5
        },
        {
          "x" : 447.48046875,
          "y" : 290.3828125,
          "pressure" : 0.5
        },
        {
          "x" : 452.1953125,
          "y" : 287.7265625,
          "pressure" : 0.5
        },
        {
          "x" : 457.12109375,
          "y" : 284.7421875,
          "pressure" : 0.5
        },
        {
          "x" : 462.0390625,
          "y" : 281.765625,
          "pressure" : 0.5
        },
        {
          "x" : 466.38671875,
          "y" : 279.16015625,
          "pressure" : 0.5
        },
        {
          "x" : 469.1640625,
          "y" : 277.26171875,
          "pressure" : 0.5
        },
        {
          "x" : 471.1015625,
          "y" : 275.671875,
          "pressure" : 0.5
        }
      ],
      "color" : 4278190080,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 481.84375,
          "y" : 220.3515625,
          "pressure" : 0.5
        },
        {
          "x" : 481.84375,
          "y" : 225.75,
          "pressure" : 0.5
        },
        {
          "x" : 481.84375,
          "y" : 235.33984375,
          "pressure" : 0.5
        },
        {
          "x" : 482.40234375,
          "y" : 247.2265625,
          "pressure" : 0.5
        },
        {
          "x" : 484.0234375,
          "y" : 259.1171875,
          "pressure" : 0.5
        },
        {
          "x" : 485.58203125,
          "y" : 267.515625,
          "pressure" : 0.5
        },
        {
          "x" : 486.71484375,
          "y" : 273.125,
          "pressure" : 0.5
        },
        {
          "x" : 487.87109375,
          "y" : 277.17578125,
          "pressure" : 0.5
        },
        {
          "x" : 488.4375,
          "y" : 279.2265625,
          "pressure" : 0.5
        },
        {
          "x" : 489.70703125,
          "y" : 282.98046875,
          "pressure" : 0.5
        },
        {
          "x" : 490.40625,
          "y" : 285.7890625,
          "pressure" : 0.5
        },
        {
          "x" : 491.29296875,
          "y" : 288.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 492.16796875,
          "y" : 291.63671875,
          "pressure" : 0.5
        },
        {
          "x" : 492.78515625,
          "y" : 293.703125,
          "pressure" : 0.5
        },
        {
          "x" : 493.3671875,
          "y" : 295.85546875,
          "pressure" : 0.5
        },
        {
          "x" : 492.265625,
          "y" : 292.65625,
          "pressure" : 0.5
        },
        {
          "x" : 491.078125,
          "y" : 290.3203125,
          "pressure" : 0.5
        },
        {
          "x" : 488.48046875,
          "y" : 283.796875,
          "pressure" : 0.5
        },
        {
          "x" : 485.13671875,
          "y" : 274.35546875,
          "pressure" : 0.5
        },
        {
          "x" : 482.390625,
          "y" : 264.54296875,
          "pressure" : 0.5
        },
        {
          "x" : 480.8203125,
          "y" : 252.20703125,
          "pressure" : 0.5
        },
        {
          "x" : 480.56640625,
          "y" : 239.078125,
          "pressure" : 0.5
        },
        {
          "x" : 480.56640625,
          "y" : 228.625,
          "pressure" : 0.5
        },
        {
          "x" : 480.90234375,
          "y" : 221.51953125,
          "pressure" : 0.5
        },
        {
          "x" : 481.73046875,
          "y" : 216.66015625,
          "pressure" : 0.5
        },
        {
          "x" : 482.51953125,
          "y" : 214.2421875,
          "pressure" : 0.5
        },
        {
          "x" : 484.6875,
          "y" : 212.15625,
          "pressure" : 0.5
        },
        {
          "x" : 488.0859375,
          "y" : 210.8515625,
          "pressure" : 0.5
        },
        {
          "x" : 493.640625,
          "y" : 209.37109375,
          "pressure" : 0.5
        },
        {
          "x" : 500.91796875,
          "y" : 207.9609375,
          "pressure" : 0.5
        },
        {
          "x" : 509.38671875,
          "y" : 206.8828125,
          "pressure" : 0.5
        },
        {
          "x" : 518.25,
          "y" : 206.28515625,
          "pressure" : 0.5
        },
        {
          "x" : 525.6328125,
          "y" : 206.04296875,
          "pressure" : 0.5
        },
        {
          "x" : 531.3671875,
          "y" : 206.04296875,
          "pressure" : 0.5
        },
        {
          "x" : 535.93359375,
          "y" : 206.04296875,
          "pressure" : 0.5
        },
        {
          "x" : 538.55078125,
          "y" : 206.0625,
          "pressure" : 0.5
        },
        {
          "x" : 540.37890625,
          "y" : 206.9453125,
          "pressure" : 0.5
        },
        {
          "x" : 540.8515625,
          "y" : 209.51171875,
          "pressure" : 0.5
        },
        {
          "x" : 540.8515625,
          "y" : 212.3671875,
          "pressure" : 0.5
        },
        {
          "x" : 540.8515625,
          "y" : 215.93359375,
          "pressure" : 0.5
        },
        {
          "x" : 540.30859375,
          "y" : 219.1171875,
          "pressure" : 0.5
        },
        {
          "x" : 539.08203125,
          "y" : 221.9140625,
          "pressure" : 0.5
        },
        {
          "x" : 537.22265625,
          "y" : 224.546875,
          "pressure" : 0.5
        },
        {
          "x" : 534.52734375,
          "y" : 227.49609375,
          "pressure" : 0.5
        },
        {
          "x" : 531.59765625,
          "y" : 230.1796875,
          "pressure" : 0.5
        },
        {
          "x" : 527.765625,
          "y" : 233.26171875,
          "pressure" : 0.5
        },
        {
          "x" : 523.78515625,
          "y" : 236.3046875,
          "pressure" : 0.5
        },
        {
          "x" : 520.59375,
          "y" : 238.38671875,
          "pressure" : 0.5
        },
        {
          "x" : 518.1875,
          "y" : 239.71484375,
          "pressure" : 0.5
        },
        {
          "x" : 516.16796875,
          "y" : 240.28125,
          "pressure" : 0.5
        },
        {
          "x" : 513.89453125,
          "y" : 240.28125,
          "pressure" : 0.5
        },
        {
          "x" : 510.453125,
          "y" : 241.3046875,
          "pressure" : 0.5
        },
        {
          "x" : 505.7265625,
          "y" : 243.58203125,
          "pressure" : 0.5
        },
        {
          "x" : 500.69140625,
          "y" : 245.96484375,
          "pressure" : 0.5
        },
        {
          "x" : 496.390625,
          "y" : 247.85546875,
          "pressure" : 0.5
        },
        {
          "x" : 493.20703125,
          "y" : 249.2890625,
          "pressure" : 0.5
        },
        {
          "x" : 491.34765625,
          "y" : 250.09375,
          "pressure" : 0.5
        },
        {
          "x" : 494.01171875,
          "y" : 250.62109375,
          "pressure" : 0.5
        },
        {
          "x" : 496.7890625,
          "y" : 251.66015625,
          "pressure" : 0.5
        },
        {
          "x" : 499.4140625,
          "y" : 252.82421875,
          "pressure" : 0.5
        },
        {
          "x" : 503.609375,
          "y" : 254.74609375,
          "pressure" : 0.5
        },
        {
          "x" : 509.73828125,
          "y" : 257.45703125,
          "pressure" : 0.5
        },
        {
          "x" : 518.52734375,
          "y" : 261.6015625,
          "pressure" : 0.5
        },
        {
          "x" : 530.51953125,
          "y" : 267.59765625,
          "pressure" : 0.5
        },
        {
          "x" : 543.96875,
          "y" : 274.47265625,
          "pressure" : 0.5
        },
        {
          "x" : 556.94921875,
          "y" : 281.83203125,
          "pressure" : 0.5
        },
        {
          "x" : 568.32421875,
          "y" : 288.76171875,
          "pressure" : 0.5
        },
        {
          "x" : 576.05859375,
          "y" : 293.38671875,
          "pressure" : 0.5
        },
        {
          "x" : 580.609375,
          "y" : 296.2421875,
          "pressure" : 0.5
        },
        {
          "x" : 583.375,
          "y" : 298.109375,
          "pressure" : 0.5
        },
        {
          "x" : 585.140625,
          "y" : 299.421875,
          "pressure" : 0.5
        }
      ],
      "color" : 4278190080,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 593.36328125,
          "y" : 205.30859375,
          "pressure" : 0.5
        },
        {
          "x" : 593.61328125,
          "y" : 212.31640625,
          "pressure" : 0.5
        },
        {
          "x" : 593.61328125,
          "y" : 221.25390625,
          "pressure" : 0.5
        },
        {
          "x" : 594.58984375,
          "y" : 233.94140625,
          "pressure" : 0.5
        },
        {
          "x" : 595.96875,
          "y" : 246.05078125,
          "pressure" : 0.5
        },
        {
          "x" : 597.59765625,
          "y" : 256.0703125,
          "pressure" : 0.5
        },
        {
          "x" : 599.3828125,
          "y" : 264.45703125,
          "pressure" : 0.5
        },
        {
          "x" : 600.51953125,
          "y" : 269.796875,
          "pressure" : 0.5
        },
        {
          "x" : 601.44921875,
          "y" : 273.33203125,
          "pressure" : 0.5
        },
        {
          "x" : 601.99609375,
          "y" : 275.51953125,
          "pressure" : 0.5
        },
        {
          "x" : 603.34375,
          "y" : 279.125,
          "pressure" : 0.5
        },
        {
          "x" : 604.4375,
          "y" : 281.703125,
          "pressure" : 0.5
        },
        {
          "x" : 605.39453125,
          "y" : 284.21484375,
          "pressure" : 0.5
        },
        {
          "x" : 606.125,
          "y" : 286.08203125,
          "pressure" : 0.5
        },
        {
          "x" : 607.17578125,
          "y" : 288.0234375,
          "pressure" : 0.5
        }
      ],
      "color" : 4278190080,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 636.6484375,
          "y" : 199.66015625,
          "pressure" : 0.5
        },
        {
          "x" : 636.6484375,
          "y" : 204.68359375,
          "pressure" : 0.5
        },
        {
          "x" : 636.84765625,
          "y" : 216.26953125,
          "pressure" : 0.5
        },
        {
          "x" : 638.375,
          "y" : 229.6953125,
          "pressure" : 0.5
        },
        {
          "x" : 640.97265625,
          "y" : 243.08203125,
          "pressure" : 0.5
        },
        {
          "x" : 643.13671875,
          "y" : 253.87109375,
          "pressure" : 0.5
        },
        {
          "x" : 644.8125,
          "y" : 260.45703125,
          "pressure" : 0.5
        },
        {
          "x" : 645.87890625,
          "y" : 265.12890625,
          "pressure" : 0.5
        },
        {
          "x" : 646.4765625,
          "y" : 267.65625,
          "pressure" : 0.5
        },
        {
          "x" : 647.41015625,
          "y" : 269.75390625,
          "pressure" : 0.5
        },
        {
          "x" : 648.23828125,
          "y" : 271.75,
          "pressure" : 0.5
        },
        {
          "x" : 648.8203125,
          "y" : 274.5234375,
          "pressure" : 0.5
        },
        {
          "x" : 649.125,
          "y" : 277.40625,
          "pressure" : 0.5
        },
        {
          "x" : 649.54296875,
          "y" : 279.51953125,
          "pressure" : 0.5
        },
        {
          "x" : 650.48046875,
          "y" : 282.015625,
          "pressure" : 0.5
        },
        {
          "x" : 650.95703125,
          "y" : 284.31640625,
          "pressure" : 0.5
        },
        {
          "x" : 651.62890625,
          "y" : 286.4296875,
          "pressure" : 0.5
        },
        {
          "x" : 654.0703125,
          "y" : 286.5859375,
          "pressure" : 0.5
        },
        {
          "x" : 657.87890625,
          "y" : 285.67578125,
          "pressure" : 0.5
        },
        {
          "x" : 664.7890625,
          "y" : 284.53125,
          "pressure" : 0.5
        },
        {
          "x" : 673.90625,
          "y" : 283.0390625,
          "pressure" : 0.5
        },
        {
          "x" : 681.234375,
          "y" : 281.6875,
          "pressure" : 0.5
        },
        {
          "x" : 686.3046875,
          "y" : 280.26953125,
          "pressure" : 0.5
        },
        {
          "x" : 690.2578125,
          "y" : 278.765625,
          "pressure" : 0.5
        },
        {
          "x" : 692.40625,
          "y" : 277.42578125,
          "pressure" : 0.5
        },
        {
          "x" : 693.87109375,
          "y" : 275,
          "pressure" : 0.5
        },
        {
          "x" : 693.98046875,
          "y" : 272.515625,
          "pressure" : 0.5
        },
        {
          "x" : 693.765625,
          "y" : 270.37890625,
          "pressure" : 0.5
        },
        {
          "x" : 693.6875,
          "y" : 267.90625,
          "pressure" : 0.5
        },
        {
          "x" : 693.6875,
          "y" : 265.29296875,
          "pressure" : 0.5
        },
        {
          "x" : 693.6875,
          "y" : 263.01171875,
          "pressure" : 0.5
        },
        {
          "x" : 693.65234375,
          "y" : 259.22265625,
          "pressure" : 0.5
        },
        {
          "x" : 692.5078125,
          "y" : 253.6953125,
          "pressure" : 0.5
        },
        {
          "x" : 690.36328125,
          "y" : 248.2578125,
          "pressure" : 0.5
        },
        {
          "x" : 688.26171875,
          "y" : 244.4921875,
          "pressure" : 0.5
        },
        {
          "x" : 686.578125,
          "y" : 242.1875,
          "pressure" : 0.5
        },
        {
          "x" : 684.73046875,
          "y" : 241.05078125,
          "pressure" : 0.5
        },
        {
          "x" : 681.7890625,
          "y" : 241.15234375,
          "pressure" : 0.5
        },
        {
          "x" : 678.796875,
          "y" : 242.0546875,
          "pressure" : 0.5
        },
        {
          "x" : 676.78125,
          "y" : 242.390625,
          "pressure" : 0.5
        },
        {
          "x" : 680.578125,
          "y" : 238.8046875,
          "pressure" : 0.5
        },
        {
          "x" : 685.9296875,
          "y" : 235.6640625,
          "pressure" : 0.5
        },
        {
          "x" : 692.8125,
          "y" : 231.96875,
          "pressure" : 0.5
        },
        {
          "x" : 700.3671875,
          "y" : 227.94921875,
          "pressure" : 0.5
        },
        {
          "x" : 706.7578125,
          "y" : 224.47265625,
          "pressure" : 0.5
        },
        {
          "x" : 711.67578125,
          "y" : 221.6171875,
          "pressure" : 0.5
        },
        {
          "x" : 715.71875,
          "y" : 218.7265625,
          "pressure" : 0.5
        },
        {
          "x" : 718.04296875,
          "y" : 216.72265625,
          "pressure" : 0.5
        },
        {
          "x" : 719.75,
          "y" : 214.90234375,
          "pressure" : 0.5
        },
        {
          "x" : 719.8671875,
          "y" : 212.1796875,
          "pressure" : 0.5
        },
        {
          "x" : 718.1796875,
          "y" : 209.375,
          "pressure" : 0.5
        },
        {
          "x" : 714.6171875,
          "y" : 205.8671875,
          "pressure" : 0.5
        },
        {
          "x" : 710.453125,
          "y" : 202.67578125,
          "pressure" : 0.5
        },
        {
          "x" : 706.34375,
          "y" : 200.234375,
          "pressure" : 0.5
        },
        {
          "x" : 702.69140625,
          "y" : 198.53515625,
          "pressure" : 0.5
        },
        {
          "x" : 699.48828125,
          "y" : 197.25390625,
          "pressure" : 0.5
        },
        {
          "x" : 696.421875,
          "y" : 196.1640625,
          "pressure" : 0.5
        },
        {
          "x" : 692.2734375,
          "y" : 194.578125,
          "pressure" : 0.5
        },
        {
          "x" : 686.59765625,
          "y" : 192.5078125,
          "pressure" : 0.5
        },
        {
          "x" : 680.375,
          "y" : 190.88671875,
          "pressure" : 0.5
        },
        {
          "x" : 674.41015625,
          "y" : 189.83203125,
          "pressure" : 0.5
        },
        {
          "x" : 669.19921875,
          "y" : 189.15625,
          "pressure" : 0.5
        },
        {
          "x" : 665.01953125,
          "y" : 188.95703125,
          "pressure" : 0.5
        },
        {
          "x" : 661.21484375,
          "y" : 188.95703125,
          "pressure" : 0.5
        },
        {
          "x" : 656.84765625,
          "y" : 188.95703125,
          "pressure" : 0.5
        },
        {
          "x" : 652.46484375,
          "y" : 188.95703125,
          "pressure" : 0.5
        },
        {
          "x" : 648.41015625,
          "y" : 189.1796875,
          "pressure" : 0.5
        },
        {
          "x" : 644.91015625,
          "y" : 189.71875,
          "pressure" : 0.5
        },
        {
          "x" : 642.625,
          "y" : 190.19140625,
          "pressure" : 0.5
        },
        {
          "x" : 640.671875,
          "y" : 190.65625,
          "pressure" : 0.5
        },
        {
          "x" : 637.68359375,
          "y" : 190.859375,
          "pressure" : 0.5
        },
        {
          "x" : 635.23828125,
          "y" : 190.859375,
          "pressure" : 0.5
        },
        {
          "x" : 632.421875,
          "y" : 190.859375,
          "pressure" : 0.5
        },
        {
          "x" : 630.2578125,
          "y" : 190.859375,
          "pressure" : 0.5
        }
      ],
      "color" : 4278190080,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 735.640625,
          "y" : 191.85546875,
          "pressure" : 0.5
        },
        {
          "x" : 735.8671875,
          "y" : 197.19140625,
          "pressure" : 0.5
        },
        {
          "x" : 735.8671875,
          "y" : 207.3515625,
          "pressure" : 0.5
        },
        {
          "x" : 735.8671875,
          "y" : 220.00390625,
          "pressure" : 0.5
        },
        {
          "x" : 735.8671875,
          "y" : 236.88671875,
          "pressure" : 0.5
        },
        {
          "x" : 735.8671875,
          "y" : 253.30078125,
          "pressure" : 0.5
        },
        {
          "x" : 735.8671875,
          "y" : 263.01171875,
          "pressure" : 0.5
        },
        {
          "x" : 735.8671875,
          "y" : 270.3359375,
          "pressure" : 0.5
        },
        {
          "x" : 735.8671875,
          "y" : 275.1953125,
          "pressure" : 0.5
        },
        {
          "x" : 735.8671875,
          "y" : 277.4296875,
          "pressure" : 0.5
        },
        {
          "x" : 738.3359375,
          "y" : 278.1953125,
          "pressure" : 0.5
        },
        {
          "x" : 744.2265625,
          "y" : 278.1953125,
          "pressure" : 0.5
        },
        {
          "x" : 755.828125,
          "y" : 278.1953125,
          "pressure" : 0.5
        },
        {
          "x" : 770.25,
          "y" : 278.1953125,
          "pressure" : 0.5
        },
        {
          "x" : 785.2890625,
          "y" : 278.1953125,
          "pressure" : 0.5
        },
        {
          "x" : 800.23046875,
          "y" : 277.91015625,
          "pressure" : 0.5
        },
        {
          "x" : 810.90625,
          "y" : 277.23828125,
          "pressure" : 0.5
        },
        {
          "x" : 817.84765625,
          "y" : 276.01953125,
          "pressure" : 0.5
        },
        {
          "x" : 823.51171875,
          "y" : 274.3203125,
          "pressure" : 0.5
        },
        {
          "x" : 826.94921875,
          "y" : 272.5703125,
          "pressure" : 0.5
        },
        {
          "x" : 828.58203125,
          "y" : 270.921875,
          "pressure" : 0.5
        },
        {
          "x" : 829.26171875,
          "y" : 268.21484375,
          "pressure" : 0.5
        },
        {
          "x" : 829.26171875,
          "y" : 262.62890625,
          "pressure" : 0.5
        },
        {
          "x" : 829.171875,
          "y" : 258.72265625,
          "pressure" : 0.5
        },
        {
          "x" : 828.984375,
          "y" : 255.859375,
          "pressure" : 0.5
        },
        {
          "x" : 828.73046875,
          "y" : 253.78125,
          "pressure" : 0.5
        },
        {
          "x" : 826.94921875,
          "y" : 251.1484375,
          "pressure" : 0.5
        },
        {
          "x" : 824.2265625,
          "y" : 249.28515625,
          "pressure" : 0.5
        },
        {
          "x" : 820.109375,
          "y" : 246.80859375,
          "pressure" : 0.5
        },
        {
          "x" : 815.87890625,
          "y" : 244.60546875,
          "pressure" : 0.5
        },
        {
          "x" : 811.83203125,
          "y" : 242.96484375,
          "pressure" : 0.5
        },
        {
          "x" : 808.04296875,
          "y" : 241.59765625,
          "pressure" : 0.5
        },
        {
          "x" : 805.01171875,
          "y" : 240.90234375,
          "pressure" : 0.5
        },
        {
          "x" : 801.375,
          "y" : 240.73046875,
          "pressure" : 0.5
        },
        {
          "x" : 796.4296875,
          "y" : 240.73046875,
          "pressure" : 0.5
        },
        {
          "x" : 790.19140625,
          "y" : 240.73046875,
          "pressure" : 0.5
        },
        {
          "x" : 783.80078125,
          "y" : 240.73046875,
          "pressure" : 0.5
        },
        {
          "x" : 778.09765625,
          "y" : 240.73046875,
          "pressure" : 0.5
        },
        {
          "x" : 773.58203125,
          "y" : 240.73046875,
          "pressure" : 0.5
        },
        {
          "x" : 771.0390625,
          "y" : 240.73046875,
          "pressure" : 0.5
        },
        {
          "x" : 768.54296875,
          "y" : 240.73046875,
          "pressure" : 0.5
        },
        {
          "x" : 765.90234375,
          "y" : 240.73046875,
          "pressure" : 0.5
        },
        {
          "x" : 763.83203125,
          "y" : 240.59765625,
          "pressure" : 0.5
        },
        {
          "x" : 769.14453125,
          "y" : 239.9609375,
          "pressure" : 0.5
        },
        {
          "x" : 779.80078125,
          "y" : 237.546875,
          "pressure" : 0.5
        },
        {
          "x" : 796.64453125,
          "y" : 232.69140625,
          "pressure" : 0.5
        },
        {
          "x" : 815.82421875,
          "y" : 226.9453125,
          "pressure" : 0.5
        },
        {
          "x" : 833.96484375,
          "y" : 221.73828125,
          "pressure" : 0.5
        },
        {
          "x" : 847.22265625,
          "y" : 217.77734375,
          "pressure" : 0.5
        },
        {
          "x" : 855.58984375,
          "y" : 214.7421875,
          "pressure" : 0.5
        },
        {
          "x" : 861.16015625,
          "y" : 212.4609375,
          "pressure" : 0.5
        },
        {
          "x" : 863.8671875,
          "y" : 211.0234375,
          "pressure" : 0.5
        },
        {
          "x" : 865.4453125,
          "y" : 208.98046875,
          "pressure" : 0.5
        },
        {
          "x" : 865.59375,
          "y" : 206.3515625,
          "pressure" : 0.5
        },
        {
          "x" : 865.07421875,
          "y" : 201.7578125,
          "pressure" : 0.5
        },
        {
          "x" : 862.62890625,
          "y" : 195.6640625,
          "pressure" : 0.5
        },
        {
          "x" : 858.8359375,
          "y" : 190.07421875,
          "pressure" : 0.5
        },
        {
          "x" : 854.58203125,
          "y" : 185.66015625,
          "pressure" : 0.5
        },
        {
          "x" : 849.64453125,
          "y" : 182.19140625,
          "pressure" : 0.5
        },
        {
          "x" : 844.9140625,
          "y" : 180.1328125,
          "pressure" : 0.5
        },
        {
          "x" : 840.25,
          "y" : 179.12890625,
          "pressure" : 0.5
        },
        {
          "x" : 834.62890625,
          "y" : 178.62890625,
          "pressure" : 0.5
        },
        {
          "x" : 827.546875,
          "y" : 178.4296875,
          "pressure" : 0.5
        },
        {
          "x" : 818.50390625,
          "y" : 178.4296875,
          "pressure" : 0.5
        },
        {
          "x" : 808.50390625,
          "y" : 178.4296875,
          "pressure" : 0.5
        },
        {
          "x" : 798.7109375,
          "y" : 178.4296875,
          "pressure" : 0.5
        },
        {
          "x" : 789.984375,
          "y" : 178.4296875,
          "pressure" : 0.5
        },
        {
          "x" : 782.99609375,
          "y" : 178.4296875,
          "pressure" : 0.5
        },
        {
          "x" : 776.75,
          "y" : 178.4296875,
          "pressure" : 0.5
        },
        {
          "x" : 770.921875,
          "y" : 178.65234375,
          "pressure" : 0.5
        },
        {
          "x" : 766.28125,
          "y" : 179.25390625,
          "pressure" : 0.5
        },
        {
          "x" : 763,
          "y" : 180.01171875,
          "pressure" : 0.5
        },
        {
          "x" : 760.9296875,
          "y" : 180.81640625,
          "pressure" : 0.5
        },
        {
          "x" : 758.75,
          "y" : 182.44921875,
          "pressure" : 0.5
        },
        {
          "x" : 754.37890625,
          "y" : 184.2734375,
          "pressure" : 0.5
        },
        {
          "x" : 750.9140625,
          "y" : 185.40625,
          "pressure" : 0.5
        },
        {
          "x" : 747.4921875,
          "y" : 186.46484375,
          "pressure" : 0.5
        },
        {
          "x" : 745.5,
          "y" : 187.0703125,
          "pressure" : 0.5
        }
      ],
      "color" : 4278190080,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 902.2890625,
          "y" : 189.70703125,
          "pressure" : 0.5
        },
        {
          "x" : 902.03125,
          "y" : 191.859375,
          "pressure" : 0.5
        },
        {
          "x" : 901.6484375,
          "y" : 197.55859375,
          "pressure" : 0.5
        },
        {
          "x" : 899.62890625,
          "y" : 209.62890625,
          "pressure" : 0.5
        },
        {
          "x" : 896.21484375,
          "y" : 226.484375,
          "pressure" : 0.5
        },
        {
          "x" : 893.37890625,
          "y" : 243.8515625,
          "pressure" : 0.5
        },
        {
          "x" : 892.31640625,
          "y" : 255.28515625,
          "pressure" : 0.5
        },
        {
          "x" : 892.31640625,
          "y" : 261.5078125,
          "pressure" : 0.5
        },
        {
          "x" : 892.31640625,
          "y" : 266.3046875,
          "pressure" : 0.5
        },
        {
          "x" : 892.6953125,
          "y" : 268.296875,
          "pressure" : 0.5
        },
        {
          "x" : 897.06640625,
          "y" : 268.359375,
          "pressure" : 0.5
        },
        {
          "x" : 903.5859375,
          "y" : 269.1875,
          "pressure" : 0.5
        },
        {
          "x" : 913.6015625,
          "y" : 270.59765625,
          "pressure" : 0.5
        },
        {
          "x" : 924.18359375,
          "y" : 272.4453125,
          "pressure" : 0.5
        },
        {
          "x" : 933.1484375,
          "y" : 274.35546875,
          "pressure" : 0.5
        },
        {
          "x" : 939.34765625,
          "y" : 275.46875,
          "pressure" : 0.5
        },
        {
          "x" : 942.69921875,
          "y" : 276.19140625,
          "pressure" : 0.5
        }
      ],
      "color" : 4278190080,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 966.49609375,
          "y" : 200.828125,
          "pressure" : 0.5
        },
        {
          "x" : 966.49609375,
          "y" : 208.34765625,
          "pressure" : 0.5
        },
        {
          "x" : 966.49609375,
          "y" : 226.41796875,
          "pressure" : 0.5
        },
        {
          "x" : 966.49609375,
          "y" : 251.2265625,
          "pressure" : 0.5
        },
        {
          "x" : 966.49609375,
          "y" : 271.83203125,
          "pressure" : 0.5
        },
        {
          "x" : 966.49609375,
          "y" : 286.38671875,
          "pressure" : 0.5
        },
        {
          "x" : 966.49609375,
          "y" : 295.296875,
          "pressure" : 0.5
        },
        {
          "x" : 966.49609375,
          "y" : 299.89453125,
          "pressure" : 0.5
        },
        {
          "x" : 972.47265625,
          "y" : 300.40625,
          "pressure" : 0.5
        },
        {
          "x" : 980.83984375,
          "y" : 300.0625,
          "pressure" : 0.5
        },
        {
          "x" : 989.83984375,
          "y" : 300.0625,
          "pressure" : 0.5
        },
        {
          "x" : 997.171875,
          "y" : 300.0625,
          "pressure" : 0.5
        },
        {
          "x" : 1002.6328125,
          "y" : 300.0625,
          "pressure" : 0.5
        },
        {
          "x" : 1005.71484375,
          "y" : 300.0625,
          "pressure" : 0.5
        },
        {
          "x" : 1007.82421875,
          "y" : 299.94140625,
          "pressure" : 0.5
        }
      ],
      "color" : 4278190080,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 975.96875,
          "y" : 235.265625,
          "pressure" : 0.5
        },
        {
          "x" : 982.140625,
          "y" : 235.265625,
          "pressure" : 0.5
        },
        {
          "x" : 992.63671875,
          "y" : 235.265625,
          "pressure" : 0.5
        },
        {
          "x" : 1004.04296875,
          "y" : 235.265625,
          "pressure" : 0.5
        },
        {
          "x" : 1013.06640625,
          "y" : 235.265625,
          "pressure" : 0.5
        },
        {
          "x" : 1019.109375,
          "y" : 235.265625,
          "pressure" : 0.5
        },
        {
          "x" : 1022.8671875,
          "y" : 235.265625,
          "pressure" : 0.5
        }
      ],
      "color" : 4278190080,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 978.14453125,
          "y" : 191.77734375,
          "pressure" : 0.5
        },
        {
          "x" : 982.51171875,
          "y" : 191.77734375,
          "pressure" : 0.5
        },
        {
          "x" : 991.06640625,
          "y" : 191.77734375,
          "pressure" : 0.5
        },
        {
          "x" : 1004.29296875,
          "y" : 191.77734375,
          "pressure" : 0.5
        },
        {
          "x" : 1017.33984375,
          "y" : 191.77734375,
          "pressure" : 0.5
        },
        {
          "x" : 1027.78515625,
          "y" : 191.77734375,
          "pressure" : 0.5
        },
        {
          "x" : 1035.0234375,
          "y" : 191.77734375,
          "pressure" : 0.5
        },
        {
          "x" : 1039.37109375,
          "y" : 191.77734375,
          "pressure" : 0.5
        },
        {
          "x" : 1041.6328125,
          "y" : 191.77734375,
          "pressure" : 0.5
        }
      ],
      "color" : 4278190080,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 144.54296875,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 153.4140625,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 173.51953125,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 201.87890625,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 230.80078125,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 257.30859375,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 281.8359375,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 303.10546875,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 323.2265625,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 344.8359375,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 367.10546875,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 385.41015625,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 401.57421875,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 422.78125,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 442.484375,
          "y" : 397.75,
          "pressure" : 0.5
        },
        {
          "x" : 459.3984375,
          "y" : 397.4453125,
          "pressure" : 0.5
        },
        {
          "x" : 478.75,
          "y" : 396.1953125,
          "pressure" : 0.5
        },
        {
          "x" : 496.08984375,
          "y" : 394.640625,
          "pressure" : 0.5
        },
        {
          "x" : 511.65625,
          "y" : 393.4296875,
          "pressure" : 0.5
        },
        {
          "x" : 529.50390625,
          "y" : 392.15625,
          "pressure" : 0.5
        },
        {
          "x" : 550.31640625,
          "y" : 390.65234375,
          "pressure" : 0.5
        },
        {
          "x" : 574.24609375,
          "y" : 389.234375,
          "pressure" : 0.5
        },
        {
          "x" : 602.31640625,
          "y" : 388.45703125,
          "pressure" : 0.5
        },
        {
          "x" : 632.43359375,
          "y" : 388.265625,
          "pressure" : 0.5
        },
        {
          "x" : 662.375,
          "y" : 388.265625,
          "pressure" : 0.5
        },
        {
          "x" : 693.21875,
          "y" : 388.55078125,
          "pressure" : 0.5
        },
        {
          "x" : 725.52734375,
          "y" : 389.640625,
          "pressure" : 0.5
        },
        {
          "x" : 758.03125,
          "y" : 390.84765625,
          "pressure" : 0.5
        },
        {
          "x" : 797.45703125,
          "y" : 392.16796875,
          "pressure" : 0.5
        },
        {
          "x" : 835.4765625,
          "y" : 393.83984375,
          "pressure" : 0.5
        },
        {
          "x" : 874.89453125,
          "y" : 396.1328125,
          "pressure" : 0.5
        },
        {
          "x" : 919.2265625,
          "y" : 399.44140625,
          "pressure" : 0.5
        },
        {
          "x" : 964.10546875,
          "y" : 403.66015625,
          "pressure" : 0.5
        },
        {
          "x" : 1002.12109375,
          "y" : 407.11328125,
          "pressure" : 0.5
        },
        {
          "x" : 1023.1796875,
          "y" : 408.71484375,
          "pressure" : 0.5
        },
        {
          "x" : 1036.48046875,
          "y" : 409.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 1045.203125,
          "y" : 410.90234375,
          "pressure" : 0.5
        },
        {
          "x" : 1049.87109375,
          "y" : 411.83203125,
          "pressure" : 0.5
        }
      ],
      "color" : 4294198070,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 87.84375,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 90.1015625,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 98.1953125,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 119.21875,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 150.33984375,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 180.2109375,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 211.8828125,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 247.37890625,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 282.55859375,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 317.80078125,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 351.99609375,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 385.56640625,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 418.0703125,
          "y" : 455.52734375,
          "pressure" : 0.5
        },
        {
          "x" : 452.60546875,
          "y" : 455.68359375,
          "pressure" : 0.5
        },
        {
          "x" : 489.12890625,
          "y" : 456.69140625,
          "pressure" : 0.5
        },
        {
          "x" : 529.953125,
          "y" : 457.78515625,
          "pressure" : 0.5
        },
        {
          "x" : 573.80078125,
          "y" : 458.02734375,
          "pressure" : 0.5
        },
        {
          "x" : 621.8671875,
          "y" : 456.33984375,
          "pressure" : 0.5
        },
        {
          "x" : 671.36328125,
          "y" : 453.17578125,
          "pressure" : 0.5
        },
        {
          "x" : 715.828125,
          "y" : 450.87109375,
          "pressure" : 0.5
        },
        {
          "x" : 764.6796875,
          "y" : 450.04296875,
          "pressure" : 0.5
        },
        {
          "x" : 816.48046875,
          "y" : 452.01171875,
          "pressure" : 0.5
        },
        {
          "x" : 859.33203125,
          "y" : 455.94140625,
          "pressure" : 0.5
        },
        {
          "x" : 897.88671875,
          "y" : 460.53125,
          "pressure" : 0.5
        },
        {
          "x" : 936.4609375,
          "y" : 465.3046875,
          "pressure" : 0.5
        },
        {
          "x" : 969.51171875,
          "y" : 469.79296875,
          "pressure" : 0.5
        },
        {
          "x" : 995.38671875,
          "y" : 474.125,
          "pressure" : 0.5
        },
        {
          "x" : 1013.5078125,
          "y" : 477.3828125,
          "pressure" : 0.5
        },
        {
          "x" : 1027.7578125,
          "y" : 479.83203125,
          "pressure" : 0.5
        },
        {
          "x" : 1041.015625,
          "y" : 482.109375,
          "pressure" : 0.5
        },
        {
          "x" : 1052.9609375,
          "y" : 484.30078125,
          "pressure" : 0.5
        },
        {
          "x" : 1063.9375,
          "y" : 486.30859375,
          "pressure" : 0.5
        },
        {
          "x" : 1073.48046875,
          "y" : 488.09765625,
          "pressure" : 0.5
        },
        {
          "x" : 1081.84765625,
          "y" : 489.7734375,
          "pressure" : 0.5
        },
        {
          "x" : 1089.45703125,
          "y" : 491.265625,
          "pressure" : 0.5
        },
        {
          "x" : 1097.453125,
          "y" : 492.61328125,
          "pressure" : 0.5
        },
        {
          "x" : 1106.1875,
          "y" : 494.01953125,
          "pressure" : 0.5
        },
        {
          "x" : 1114.51171875,
          "y" : 495.6796875,
          "pressure" : 0.5
        },
        {
          "x" : 1120.7265625,
          "y" : 497.1875,
          "pressure" : 0.5
        },
        {
          "x" : 1125.515625,
          "y" : 498.27734375,
          "pressure" : 0.5
        },
        {
          "x" : 1129.09375,
          "y" : 499.09765625,
          "pressure" : 0.5
        },
        {
          "x" : 1131.3203125,
          "y" : 499.953125,
          "pressure" : 0.5
        }
      ],
      "color" : 4283215696,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 45,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 47.19921875,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 57.63671875,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 80.4453125,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 114.54296875,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 161.18359375,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 215.58984375,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 274.38671875,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 336.0234375,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 395.21875,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 453.32421875,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 502.61328125,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 544.34765625,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 586.796875,
          "y" : 529.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 625.08984375,
          "y" : 529.9453125,
          "pressure" : 0.5
        },
        {
          "x" : 658.23828125,
          "y" : 531.1953125,
          "pressure" : 0.5
        },
        {
          "x" : 683.140625,
          "y" : 533.07421875,
          "pressure" : 0.5
        },
        {
          "x" : 703.1796875,
          "y" : 535.4140625,
          "pressure" : 0.5
        },
        {
          "x" : 721.48046875,
          "y" : 537.5625,
          "pressure" : 0.5
        },
        {
          "x" : 735.83203125,
          "y" : 539.02734375,
          "pressure" : 0.5
        },
        {
          "x" : 748.90234375,
          "y" : 540.16015625,
          "pressure" : 0.5
        },
        {
          "x" : 762.69921875,
          "y" : 540.87109375,
          "pressure" : 0.5
        },
        {
          "x" : 778.484375,
          "y" : 541.0078125,
          "pressure" : 0.5
        },
        {
          "x" : 796.59765625,
          "y" : 541.53125,
          "pressure" : 0.5
        },
        {
          "x" : 813.23046875,
          "y" : 542.390625,
          "pressure" : 0.5
        },
        {
          "x" : 833.28515625,
          "y" : 543.71875,
          "pressure" : 0.5
        },
        {
          "x" : 856.890625,
          "y" : 546.01953125,
          "pressure" : 0.5
        },
        {
          "x" : 880.9453125,
          "y" : 549.59375,
          "pressure" : 0.5
        },
        {
          "x" : 909.68359375,
          "y" : 554.23828125,
          "pressure" : 0.5
        },
        {
          "x" : 941.38671875,
          "y" : 559.08203125,
          "pressure" : 0.5
        },
        {
          "x" : 973.2265625,
          "y" : 564.26953125,
          "pressure" : 0.5
        },
        {
          "x" : 998.9921875,
          "y" : 568.25,
          "pressure" : 0.5
        },
        {
          "x" : 1019.7265625,
          "y" : 570.18359375,
          "pressure" : 0.5
        },
        {
          "x" : 1036.890625,
          "y" : 571.359375,
          "pressure" : 0.5
        },
        {
          "x" : 1047.54296875,
          "y" : 571.85546875,
          "pressure" : 0.5
        },
        {
          "x" : 1055.83984375,
          "y" : 571.85546875,
          "pressure" : 0.5
        },
        {
          "x" : 1064.10546875,
          "y" : 571.85546875,
          "pressure" : 0.5
        },
        {
          "x" : 1073.73828125,
          "y" : 572.0390625,
          "pressure" : 0.5
        },
        {
          "x" : 1085.93359375,
          "y" : 572.34765625,
          "pressure" : 0.5
        },
        {
          "x" : 1098.15625,
          "y" : 572.765625,
          "pressure" : 0.5
        },
        {
          "x" : 1108.1796875,
          "y" : 573.05859375,
          "pressure" : 0.5
        },
        {
          "x" : 1115.2265625,
          "y" : 573.05859375,
          "pressure" : 0.5
        },
        {
          "x" : 1118.890625,
          "y" : 573.2265625,
          "pressure" : 0.5
        },
        {
          "x" : 1121.6953125,
          "y" : 573.39453125,
          "pressure" : 0.5
        },
        {
          "x" : 1124.24609375,
          "y" : 573.39453125,
          "pressure" : 0.5
        },
        {
          "x" : 1125.8671875,
          "y" : 575.02734375,
          "pressure" : 0.5
        }
      ],
      "color" : 4280391411,
      "width" : 10
    },
    {
      "points" : [
        {
          "x" : 16.84765625,
          "y" : 593.47265625,
          "pressure" : 0.5
        },
        {
          "x" : 22.80859375,
          "y" : 593.47265625,
          "pressure" : 0.5
        },
        {
          "x" : 39.98046875,
          "y" : 593.47265625,
          "pressure" : 0.5
        },
        {
          "x" : 72.8125,
          "y" : 593.47265625,
          "pressure" : 0.5
        },
        {
          "x" : 118.05078125,
          "y" : 593.47265625,
          "pressure" : 0.5
        },
        {
          "x" : 169.734375,
          "y" : 593.47265625,
          "pressure" : 0.5
        },
        {
          "x" : 216.265625,
          "y" : 593.47265625,
          "pressure" : 0.5
        },
        {
          "x" : 266.79296875,
          "y" : 593.47265625,
          "pressure" : 0.5
        },
        {
          "x" : 319.7421875,
          "y" : 593.03515625,
          "pressure" : 0.5
        },
        {
          "x" : 358.90625,
          "y" : 591.6484375,
          "pressure" : 0.5
        },
        {
          "x" : 405.79296875,
          "y" : 589.58984375,
          "pressure" : 0.5
        },
        {
          "x" : 458.38671875,
          "y" : 588.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 500.421875,
          "y" : 588.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 550.19140625,
          "y" : 588.48046875,
          "pressure" : 0.5
        },
        {
          "x" : 605.96875,
          "y" : 589.1328125,
          "pressure" : 0.5
        },
        {
          "x" : 657.78125,
          "y" : 590.7890625,
          "pressure" : 0.5
        },
        {
          "x" : 712.015625,
          "y" : 592.5703125,
          "pressure" : 0.5
        },
        {
          "x" : 767.7421875,
          "y" : 593.84375,
          "pressure" : 0.5
        },
        {
          "x" : 823.5390625,
          "y" : 595.12890625,
          "pressure" : 0.5
        },
        {
          "x" : 879.20703125,
          "y" : 596.9453125,
          "pressure" : 0.5
        },
        {
          "x" : 936.0859375,
          "y" : 600.265625,
          "pressure" : 0.5
        },
        {
          "x" : 991.69921875,
          "y" : 605.27734375,
          "pressure" : 0.5
        },
        {
          "x" : 1035.9921875,
          "y" : 609.8359375,
          "pressure" : 0.5
        },
        {
          "x" : 1071.140625,
          "y" : 612.98046875,
          "pressure" : 0.5
        },
        {
          "x" : 1105.32421875,
          "y" : 615.48828125,
          "pressure" : 0.5
        },
        {
          "x" : 1130.77734375,
          "y" : 617.69140625,
          "pressure" : 0.5
        },
        {
          "x" : 1149.078125,
          "y" : 619.640625,
          "pressure" : 0.5
        },
        {
          "x" : 1166.15234375,
          "y" : 621.54296875,
          "pressure" : 0.5
        }
      ],
      "color" : 4294961979,
      "width" : 10
    }
  ]
}
''';
